dokuwikixmlrpc is a python module which implements DokuWikis XML-RPC interface.

It can be used to send/retrieve data from remote Dokuwiki instances.

The module can be executed as a standalone script (this is mainly for testing
purposes). Call ::

  python dokuwikixmlrpc.py --help

for more information.

Copyright 2009 by Michael Klier <chi@chimeric.de>

See `LICENSE.txt <LICENSE.txt>`_ for license info.